==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkClipDataSet.java <==
// java wrapper for vtkClipDataSet object
//

package vtk;
import vtk.*;

public class vtkClipDataSet extends vtkUnstructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(double id0);
  public void SetValue(double id0)
    { SetValue_2(id0); }

  private native double GetValue_3();
  public double GetValue()
    { return GetValue_3(); }

  private native void SetUseValueAsOffset_4(boolean id0);
  public void SetUseValueAsOffset(boolean id0)
    { SetUseValueAsOffset_4(id0); }

  private native boolean GetUseValueAsOffset_5();
  public boolean GetUseValueAsOffset()
    { return GetUseValueAsOffset_5(); }

  private native void UseValueAsOffsetOn_6();
  public void UseValueAsOffsetOn()
    { UseValueAsOffsetOn_6(); }

  private native void UseValueAsOffsetOff_7();
  public void UseValueAsOffsetOff()
    { UseValueAsOffsetOff_7(); }

  private native void SetInsideOut_8(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_8(id0); }

  private native int GetInsideOut_9();
  public int GetInsideOut()
    { return GetInsideOut_9(); }

  private native void InsideOutOn_10();
  public void InsideOutOn()
    { InsideOutOn_10(); }

  private native void InsideOutOff_11();
  public void InsideOutOff()
    { InsideOutOff_11(); }

  private native void SetClipFunction_12(vtkImplicitFunction id0);
  public void SetClipFunction(vtkImplicitFunction id0)
    { SetClipFunction_12(id0); }

  private native long GetClipFunction_13();
  public vtkImplicitFunction GetClipFunction() {
    long temp = GetClipFunction_13();

    if (temp == 0) return null;
    return (vtkImplicitFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetGenerateClipScalars_14(int id0);
  public void SetGenerateClipScalars(int id0)
    { SetGenerateClipScalars_14(id0); }

  private native int GetGenerateClipScalars_15();
  public int GetGenerateClipScalars()
    { return GetGenerateClipScalars_15(); }

  private native void GenerateClipScalarsOn_16();
  public void GenerateClipScalarsOn()
    { GenerateClipScalarsOn_16(); }

  private native void GenerateClipScalarsOff_17();
  public void GenerateClipScalarsOff()
    { GenerateClipScalarsOff_17(); }

  private native void SetGenerateClippedOutput_18(int id0);
  public void SetGenerateClippedOutput(int id0)
    { SetGenerateClippedOutput_18(id0); }

  private native int GetGenerateClippedOutput_19();
  public int GetGenerateClippedOutput()
    { return GetGenerateClippedOutput_19(); }

  private native void GenerateClippedOutputOn_20();
  public void GenerateClippedOutputOn()
    { GenerateClippedOutputOn_20(); }

  private native void GenerateClippedOutputOff_21();
  public void GenerateClippedOutputOff()
    { GenerateClippedOutputOff_21(); }

  private native void SetMergeTolerance_22(double id0);
  public void SetMergeTolerance(double id0)
    { SetMergeTolerance_22(id0); }

  private native double GetMergeToleranceMinValue_23();
  public double GetMergeToleranceMinValue()
    { return GetMergeToleranceMinValue_23(); }

  private native double GetMergeToleranceMaxValue_24();
  public double GetMergeToleranceMaxValue()
    { return GetMergeToleranceMaxValue_24(); }

  private native double GetMergeTolerance_25();
  public double GetMergeTolerance()
    { return GetMergeTolerance_25(); }

  private native long GetClippedOutput_26();
  public vtkUnstructuredGrid GetClippedOutput() {
    long temp = GetClippedOutput_26();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLocator_27(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_27(id0); }

  private native long GetLocator_28();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_28();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CreateDefaultLocator_29();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_29(); }

  private native int GetMTime_30();
  public int GetMTime()
    { return GetMTime_30(); }

  private native void SetOutputPointsPrecision_31(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_31(id0); }

  private native int GetOutputPointsPrecisionMinValue_32();
  public int GetOutputPointsPrecisionMinValue()
    { return GetOutputPointsPrecisionMinValue_32(); }

  private native int GetOutputPointsPrecisionMaxValue_33();
  public int GetOutputPointsPrecisionMaxValue()
    { return GetOutputPointsPrecisionMaxValue_33(); }

  private native int GetOutputPointsPrecision_34();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_34(); }

  public vtkClipDataSet() { super(); }

  public vtkClipDataSet(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkClipDataSet.java <==
// java wrapper for vtkClipDataSet object
//

package vtk;
import vtk.*;

public class vtkClipDataSet extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(double id0);
  public void SetValue(double id0)
    { SetValue_2(id0); }

  private native double GetValue_3();
  public double GetValue()
    { return GetValue_3(); }

  private native void SetUseValueAsOffset_4(boolean id0);
  public void SetUseValueAsOffset(boolean id0)
    { SetUseValueAsOffset_4(id0); }

  private native boolean GetUseValueAsOffset_5();
  public boolean GetUseValueAsOffset()
    { return GetUseValueAsOffset_5(); }

  private native void UseValueAsOffsetOn_6();
  public void UseValueAsOffsetOn()
    { UseValueAsOffsetOn_6(); }

  private native void UseValueAsOffsetOff_7();
  public void UseValueAsOffsetOff()
    { UseValueAsOffsetOff_7(); }

  private native void SetInsideOut_8(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_8(id0); }

  private native int GetInsideOut_9();
  public int GetInsideOut()
    { return GetInsideOut_9(); }

  private native void InsideOutOn_10();
  public void InsideOutOn()
    { InsideOutOn_10(); }

  private native void InsideOutOff_11();
  public void InsideOutOff()
    { InsideOutOff_11(); }

  private native void SetClipFunction_12(vtkImplicitFunction id0);
  public void SetClipFunction(vtkImplicitFunction id0)
    { SetClipFunction_12(id0); }

  private native long GetClipFunction_13();
  public vtkImplicitFunction GetClipFunction() {
    long temp = GetClipFunction_13();

    if (temp == 0) return null;
    return (vtkImplicitFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGenerateClipScalars_14(int id0);
  public void SetGenerateClipScalars(int id0)
    { SetGenerateClipScalars_14(id0); }

  private native int GetGenerateClipScalars_15();
  public int GetGenerateClipScalars()
    { return GetGenerateClipScalars_15(); }

  private native void GenerateClipScalarsOn_16();
  public void GenerateClipScalarsOn()
    { GenerateClipScalarsOn_16(); }

  private native void GenerateClipScalarsOff_17();
  public void GenerateClipScalarsOff()
    { GenerateClipScalarsOff_17(); }

  private native void SetGenerateClippedOutput_18(int id0);
  public void SetGenerateClippedOutput(int id0)
    { SetGenerateClippedOutput_18(id0); }

  private native int GetGenerateClippedOutput_19();
  public int GetGenerateClippedOutput()
    { return GetGenerateClippedOutput_19(); }

  private native void GenerateClippedOutputOn_20();
  public void GenerateClippedOutputOn()
    { GenerateClippedOutputOn_20(); }

  private native void GenerateClippedOutputOff_21();
  public void GenerateClippedOutputOff()
    { GenerateClippedOutputOff_21(); }

  private native void SetMergeTolerance_22(double id0);
  public void SetMergeTolerance(double id0)
    { SetMergeTolerance_22(id0); }

  private native double GetMergeToleranceMinValue_23();
  public double GetMergeToleranceMinValue()
    { return GetMergeToleranceMinValue_23(); }

  private native double GetMergeToleranceMaxValue_24();
  public double GetMergeToleranceMaxValue()
    { return GetMergeToleranceMaxValue_24(); }

  private native double GetMergeTolerance_25();
  public double GetMergeTolerance()
    { return GetMergeTolerance_25(); }

  private native long GetClippedOutput_26();
  public vtkUnstructuredGrid GetClippedOutput() {
    long temp = GetClippedOutput_26();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLocator_27(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_27(id0); }

  private native long GetLocator_28();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_28();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_29();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_29(); }

  private native int GetMTime_30();
  public int GetMTime()
    { return GetMTime_30(); }

  private native void SetOutputPointsPrecision_31(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_31(id0); }

  private native int GetOutputPointsPrecisionMinValue_32();
  public int GetOutputPointsPrecisionMinValue()
    { return GetOutputPointsPrecisionMinValue_32(); }

  private native int GetOutputPointsPrecisionMaxValue_33();
  public int GetOutputPointsPrecisionMaxValue()
    { return GetOutputPointsPrecisionMaxValue_33(); }

  private native int GetOutputPointsPrecision_34();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_34(); }

  public vtkClipDataSet() { super(); }

  public vtkClipDataSet(long id) { super(id); }
  public native long   VTKInit();

}
